==> haskell-assoc-1.0.2-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-assoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 assoc
version:              1.0.2
visibility:           public
id:                   assoc-1.0.2-KszucIphJXC9kmyIGebY0z
key:                  assoc-1.0.2-KszucIphJXC9kmyIGebY0z
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             swap and assoc: Symmetric and Semigroupy Bifunctors
description:
    Provides generalisations of
    @swap :: (a,b) -> (b,a)@ and
    @assoc :: ((a,b),c) -> (a,(b,c))@
    to
    @Bifunctor@s supporting similar operations (e.g. @Either@, @These@).

category:             Data
abi:                  6034db948d5fa1afb44c02f1a7fe1f24
exposed:              True
exposed-modules:      Data.Bifunctor.Assoc Data.Bifunctor.Swap
import-dirs:          /usr/lib/ghc-8.10.4/site-local/assoc-1.0.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/assoc-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/assoc-1.0.2
hs-libraries:         HSassoc-1.0.2-KszucIphJXC9kmyIGebY0z
depends:
    base-4.14.1.0 bifunctors-5.5.10-38cV7p5n9nUD3Qnlyl7mCa
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C

haddock-interfaces:   /usr/share/doc/haskell-assoc/html/assoc.haddock
haddock-html:         /usr/share/doc/haskell-assoc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-assoc-1.0.2-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-assoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 assoc
version:              1.0.2
visibility:           public
id:                   assoc-1.0.2-103zAoDppygKUKtlFukmFI
key:                  assoc-1.0.2-103zAoDppygKUKtlFukmFI
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             swap and assoc: Symmetric and Semigroupy Bifunctors
description:
    Provides generalisations of
    @swap :: (a,b) -> (b,a)@ and
    @assoc :: ((a,b),c) -> (a,(b,c))@
    to
    @Bifunctor@s supporting similar operations (e.g. @Either@, @These@).

category:             Data
abi:                  e47fae079e6287bc81d14f07290cc410
exposed:              True
exposed-modules:      Data.Bifunctor.Assoc Data.Bifunctor.Swap
import-dirs:          /usr/lib/ghc-8.10.4/site-local/assoc-1.0.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/assoc-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/assoc-1.0.2
hs-libraries:         HSassoc-1.0.2-103zAoDppygKUKtlFukmFI
depends:
    base-4.14.1.0 bifunctors-5.5.10-C0q6BBUbuaGU2wiHSyotw
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C

haddock-interfaces:   /usr/share/doc/haskell-assoc/html/assoc.haddock
haddock-html:         /usr/share/doc/haskell-assoc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
